==> activity-center-api-3.5.36-sources.jar: cn/com/duiba/activity/center/api/params/alipayactivityredpack/AlipayActivityConfigParam.java <==
package cn.com.duiba.activity.center.api.params.alipayactivityredpack;

import java.io.Serializable;
import java.util.Date;

/**
 * @author cjw
 * @version 1.0.0
 * @ClassName AlipayActivityConfigParam.java
 * @Description
 * @createTime 2022年11月18日 18:07:00
 */
public class AlipayActivityConfigParam implements Serializable {

    private static final long serialVersionUID = 108769983619383150L;
    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 主键
     */
    private Long id;

    /**
     * 卡券总数
     */
    private String redpackActivityCardTotal;

    /**
     * 红包使用说明
     */
    private String redpackActivityDescription;

    /**
     * 红包发放结束时间
     */
    private Date redpackActivityEndTime;

    /**
     * 红包活动id
     */
    private String redpackActivityId;

    /**
     * 渠道红包活动名称描述
     */
    private String redpackActivityName;

    /**
     * 绝对时间下的红包发放结束时间
     */
    private Date redpackActivityPeriodEndTime;

    /**
     * 相对时间下的红包领取时间(分钟为单位)
     */
    private Long redpackActivityPeriodMinutes;

    /**
     * 绝对时间下的红包发放结束时间
     */
    private Date redpackActivityPeriodStartTime;

    /**
     * 红包时间周期类型  0 绝对时间，1 相对时间
     */
    private Integer redpackActivityPeriodType;

    /**
     * 红包活动备注
     */
    private String redpackActivityRemark;

    /**
     * 红包发放开始时间
     */
    private Date redpackActivityStartTime;

    /**
     * 0.正常  1.手动失效  2.自动结束
     */
    private Integer redpackActivityStatus;

    /**
     * 红包活动主体
     */
    private String redpackActivitySubject;

    /**
     * 红包来源
     */
    private Integer redpackSource;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 折扣金额
     */
    private String discountPrice;
    /**
     * 门槛金额
     */
    private String discountThresholdPrice;

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Integer getRedpackSource() {
        return redpackSource;
    }

    public void setRedpackSource(Integer redpackSource) {
        this.redpackSource = redpackSource;
    }

    public String getDiscountPrice() {
        return discountPrice;
    }

    public void setDiscountPrice(String discountPrice) {
        this.discountPrice = discountPrice;
    }

    public String getDiscountThresholdPrice() {
        return discountThresholdPrice;
    }

    public void setDiscountThresholdPrice(String discountThresholdPrice) {
        this.discountThresholdPrice = discountThresholdPrice;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setRedpackActivityCardTotal(String redpackActivityCardTotal) {
        this.redpackActivityCardTotal = redpackActivityCardTotal;
    }

    public String getRedpackActivityCardTotal() {
        return redpackActivityCardTotal;
    }

    public void setRedpackActivityDescription(String redpackActivityDescription) {
        this.redpackActivityDescription = redpackActivityDescription;
    }

    public String getRedpackActivityDescription() {
        return redpackActivityDescription;
    }

    public void setRedpackActivityEndTime(Date redpackActivityEndTime) {
        this.redpackActivityEndTime = redpackActivityEndTime;
    }

    public Date getRedpackActivityEndTime() {
        return redpackActivityEndTime;
    }

    public void setRedpackActivityId(String redpackActivityId) {
        this.redpackActivityId = redpackActivityId;
    }

    public String getRedpackActivityId() {
        return redpackActivityId;
    }

    public void setRedpackActivityName(String redpackActivityName) {
        this.redpackActivityName = redpackActivityName;
    }

    public String getRedpackActivityName() {
        return redpackActivityName;
    }

    public void setRedpackActivityPeriodEndTime(Date redpackActivityPeriodEndTime) {
        this.redpackActivityPeriodEndTime = redpackActivityPeriodEndTime;
    }

    public Date getRedpackActivityPeriodEndTime() {
        return redpackActivityPeriodEndTime;
    }

    public void setRedpackActivityPeriodMinutes(Long redpackActivityPeriodMinutes) {
        this.redpackActivityPeriodMinutes = redpackActivityPeriodMinutes;
    }

    public Long getRedpackActivityPeriodMinutes() {
        return redpackActivityPeriodMinutes;
    }

    public void setRedpackActivityPeriodStartTime(Date redpackActivityPeriodStartTime) {
        this.redpackActivityPeriodStartTime = redpackActivityPeriodStartTime;
    }

    public Date getRedpackActivityPeriodStartTime() {
        return redpackActivityPeriodStartTime;
    }

    public void setRedpackActivityPeriodType(Integer redpackActivityPeriodType) {
        this.redpackActivityPeriodType = redpackActivityPeriodType;
    }

    public Integer getRedpackActivityPeriodType() {
        return redpackActivityPeriodType;
    }

    public void setRedpackActivityRemark(String redpackActivityRemark) {
        this.redpackActivityRemark = redpackActivityRemark;
    }

    public String getRedpackActivityRemark() {
        return redpackActivityRemark;
    }

    public void setRedpackActivityStartTime(Date redpackActivityStartTime) {
        this.redpackActivityStartTime = redpackActivityStartTime;
    }

    public Date getRedpackActivityStartTime() {
        return redpackActivityStartTime;
    }

    public void setRedpackActivityStatus(Integer redpackActivityStatus) {
        this.redpackActivityStatus = redpackActivityStatus;
    }

    public Integer getRedpackActivityStatus() {
        return redpackActivityStatus;
    }

    public void setRedpackActivitySubject(String redpackActivitySubject) {
        this.redpackActivitySubject = redpackActivitySubject;
    }

    public String getRedpackActivitySubject() {
        return redpackActivitySubject;
    }

}

==> activity-center-api-3.6.26-20250907.113250-10-sources.jar: cn/com/duiba/activity/center/api/params/alipayactivityredpack/AlipayActivityConfigParam.java <==
package cn.com.duiba.activity.center.api.params.alipayactivityredpack;

import java.io.Serializable;
import java.util.Date;

/**
 * @author cjw
 * @version 1.0.0
 * @ClassName AlipayActivityConfigParam.java
 * @Description
 * @createTime 2022年11月18日 18:07:00
 */
public class AlipayActivityConfigParam implements Serializable {

    private static final long serialVersionUID = 108769983619383150L;
    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModified;

    /**
     * 主键
     */
    private Long id;

    /**
     * 卡券总数
     */
    private String redpackActivityCardTotal;

    /**
     * 红包使用说明
     */
    private String redpackActivityDescription;

    /**
     * 红包发放结束时间
     */
    private Date redpackActivityEndTime;

    /**
     * 红包活动id
     */
    private String redpackActivityId;

    /**
     * 渠道红包活动名称描述
     */
    private String redpackActivityName;

    /**
     * 绝对时间下的红包发放结束时间
     */
    private Date redpackActivityPeriodEndTime;

    /**
     * 相对时间下的红包领取时间(分钟为单位)
     */
    private Long redpackActivityPeriodMinutes;

    /**
     * 绝对时间下的红包发放结束时间
     */
    private Date redpackActivityPeriodStartTime;

    /**
     * 红包时间周期类型  0 绝对时间，1 相对时间
     */
    private Integer redpackActivityPeriodType;

    /**
     * 红包活动备注
     */
    private String redpackActivityRemark;

    /**
     * 红包发放开始时间
     */
    private Date redpackActivityStartTime;

    /**
     * 0.正常  1.手动失效  2.自动结束
     */
    private Integer redpackActivityStatus;

    /**
     * 红包活动主体
     */
    private String redpackActivitySubject;

    /**
     * 红包来源
     */
    private Integer redpackSource;

    /**
     * 扩展字段
     */
    private String extra;

    /**
     * 折扣金额
     */
    private String discountPrice;
    /**
     * 门槛金额
     */
    private String discountThresholdPrice;

    /**
     * 卡种类型 1:信用卡   2:借记卡   3:借记卡或信用卡
     */
    private Integer redpackActivityCardType;

    /**
     * 银行卡卡bin配置, 英文逗号分割
     */
    private String redpackActivityCardBin;

    /**
     * 自定义说明
     */
    private String customDescription;

    public String getCustomDescription() {
        return customDescription;
    }

    public void setCustomDescription(String customDescription) {
        this.customDescription = customDescription;
    }

    public Integer getRedpackActivityCardType() {
        return redpackActivityCardType;
    }

    public void setRedpackActivityCardType(Integer redpackActivityCardType) {
        this.redpackActivityCardType = redpackActivityCardType;
    }

    public String getRedpackActivityCardBin() {
        return redpackActivityCardBin;
    }

    public void setRedpackActivityCardBin(String redpackActivityCardBin) {
        this.redpackActivityCardBin = redpackActivityCardBin;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }

    public Integer getRedpackSource() {
        return redpackSource;
    }

    public void setRedpackSource(Integer redpackSource) {
        this.redpackSource = redpackSource;
    }

    public String getDiscountPrice() {
        return discountPrice;
    }

    public void setDiscountPrice(String discountPrice) {
        this.discountPrice = discountPrice;
    }

    public String getDiscountThresholdPrice() {
        return discountThresholdPrice;
    }

    public void setDiscountThresholdPrice(String discountThresholdPrice) {
        this.discountThresholdPrice = discountThresholdPrice;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setRedpackActivityCardTotal(String redpackActivityCardTotal) {
        this.redpackActivityCardTotal = redpackActivityCardTotal;
    }

    public String getRedpackActivityCardTotal() {
        return redpackActivityCardTotal;
    }

    public void setRedpackActivityDescription(String redpackActivityDescription) {
        this.redpackActivityDescription = redpackActivityDescription;
    }

    public String getRedpackActivityDescription() {
        return redpackActivityDescription;
    }

    public void setRedpackActivityEndTime(Date redpackActivityEndTime) {
        this.redpackActivityEndTime = redpackActivityEndTime;
    }

    public Date getRedpackActivityEndTime() {
        return redpackActivityEndTime;
    }

    public void setRedpackActivityId(String redpackActivityId) {
        this.redpackActivityId = redpackActivityId;
    }

    public String getRedpackActivityId() {
        return redpackActivityId;
    }

    public void setRedpackActivityName(String redpackActivityName) {
        this.redpackActivityName = redpackActivityName;
    }

    public String getRedpackActivityName() {
        return redpackActivityName;
    }

    public void setRedpackActivityPeriodEndTime(Date redpackActivityPeriodEndTime) {
        this.redpackActivityPeriodEndTime = redpackActivityPeriodEndTime;
    }

    public Date getRedpackActivityPeriodEndTime() {
        return redpackActivityPeriodEndTime;
    }

    public void setRedpackActivityPeriodMinutes(Long redpackActivityPeriodMinutes) {
        this.redpackActivityPeriodMinutes = redpackActivityPeriodMinutes;
    }

    public Long getRedpackActivityPeriodMinutes() {
        return redpackActivityPeriodMinutes;
    }

    public void setRedpackActivityPeriodStartTime(Date redpackActivityPeriodStartTime) {
        this.redpackActivityPeriodStartTime = redpackActivityPeriodStartTime;
    }

    public Date getRedpackActivityPeriodStartTime() {
        return redpackActivityPeriodStartTime;
    }

    public void setRedpackActivityPeriodType(Integer redpackActivityPeriodType) {
        this.redpackActivityPeriodType = redpackActivityPeriodType;
    }

    public Integer getRedpackActivityPeriodType() {
        return redpackActivityPeriodType;
    }

    public void setRedpackActivityRemark(String redpackActivityRemark) {
        this.redpackActivityRemark = redpackActivityRemark;
    }

    public String getRedpackActivityRemark() {
        return redpackActivityRemark;
    }

    public void setRedpackActivityStartTime(Date redpackActivityStartTime) {
        this.redpackActivityStartTime = redpackActivityStartTime;
    }

    public Date getRedpackActivityStartTime() {
        return redpackActivityStartTime;
    }

    public void setRedpackActivityStatus(Integer redpackActivityStatus) {
        this.redpackActivityStatus = redpackActivityStatus;
    }

    public Integer getRedpackActivityStatus() {
        return redpackActivityStatus;
    }

    public void setRedpackActivitySubject(String redpackActivitySubject) {
        this.redpackActivitySubject = redpackActivitySubject;
    }

    public String getRedpackActivitySubject() {
        return redpackActivitySubject;
    }

}
